@@ -23,7 +23,7 @@ BUILD_REQUIRES = ['numpy', 'cython<3.0.0a8'] # This is need for older pip
 
 MAJOR = 2
 MINOR = 6
-MICRO = 4
+MICRO = 5
 DEV = False
 
 CLASSIFIERS = [
@@ -33,11 +33,8 @@ CLASSIFIERS = [
         'Intended Audience :: Science/Research',
         'License :: OSI Approved :: BSD License',
         'Topic :: Scientific/Engineering',
-        'Programming Language :: Python :: 2',
-        'Programming Language :: Python :: 2.7',
         'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.5',
-        'Programming Language :: Python :: 3.6',
+        "Programming Language :: Python :: 3 :: Only",
         'Programming Language :: Python :: 3.7',
         'Programming Language :: Python :: 3.8',
         'Programming Language :: Python :: 3.9',
